/******************************************************************************
 * MiniFFS : Mini Flat File System
 * This file is part of the test suite of MiniFFS
 *
 * Copyright (c) 2008-2022 986-Studio. All rights reserved.
 *
 ******************************************************************************/

#include <gtest/gtest.h>

#include <miniffs.h>
#include "get_fs.h"

TEST(FSOpening, OpeningAFileSystem)
{
    miniffs_t *fs = get_fs("simple_test.mffs");
    ASSERT_NE(fs, nullptr);
}

TEST(FSOpening, OpeningANonExistingFile)
{
    miniffs_t *fs = get_fs("i_do_not_exists.mffs");
    ASSERT_EQ(fs, nullptr);
    ASSERT_EQ(miniffs_geterror(), MINIFFS_INVALID_FS);
}

TEST(FSOpening, OpeningFsWithWrongMagic)
{
    miniffs_t *fs = get_fs("wrong_magic.mffs");
    ASSERT_EQ(fs, nullptr);
    ASSERT_EQ(miniffs_geterror(), MINIFFS_INVALID_FS);
}

TEST(FSOpening, OpeningFsWithWrongVersion)
{
    miniffs_t *fs = get_fs("wrong_version.mffs");
    ASSERT_EQ(fs, nullptr);
    ASSERT_EQ(miniffs_geterror(), MINIFFS_INVALID_FS);
}

TEST(FSOpening, OpeningFsWithWrongNameLen)
{
    miniffs_t *fs = get_fs("wrong_namelen.mffs");
    ASSERT_EQ(fs, nullptr);
    ASSERT_EQ(miniffs_geterror(), MINIFFS_INVALID_FS);
}

TEST(FSOpening, OpeningFsWithWrongExtLen)
{
    miniffs_t *fs = get_fs("wrong_extlen.mffs");
    ASSERT_EQ(fs, nullptr);
    ASSERT_EQ(miniffs_geterror(), MINIFFS_INVALID_FS);
}